@@ -6,10 +6,10 @@ from smdc.format.util import escape_quotes
 
 
 def escape_cypher(string):
-    r = escape_quotes(string)
+    # r = escape_quotes(string)
     # Note: CYPHER doesn't allow putting semicolons in text, for some reason. This is lossy!
-    r = r.replace(";", ",")
-    r = r.replace("\\u", "\\\\u")
+    # r = r.replace(";", ",")
+    r = string.replace("\\u", "\\\\u")
     if r and r[-1] == '\\':
         r += ' '
     return r
@@ -20,10 +20,11 @@ def to_cyper(parsed_notes: [Note]):
     for name, note in parsed_notes.items():
         line = "CREATE ("
         if note.tags:
-            line += ":" + ":".join(note.tags)
-        line += " { name: '" + escape_cypher(name) + "', content: '" + escape_cypher(note.content) + "'"
+            line += ":" + ":".join(note.tags) + " {"
+        properties = []
         for property, value in note.properties.items():
-            line += ", " + property + ": '" + escape_cypher(str(value)) + "'"
+            properties.append(property + ": '" + escape_cypher(str(value)) + "'")
+        line += ", ".join(properties)
         line += "});"
         lines.append(line)
 
