@@ -2,7 +2,7 @@ from smdc.format import Format
 from smdc.note import Note, Relationship
 import io
 import os
-from smdc.format.util import parse_yaml_header, get_tags_from_line, get_wikilinks_from_line, PUNCTUATION
+from smdc.format.util import parse_yaml_header, get_tags_from_line, get_wikilinks_from_line, PUNCTUATION, markdownToHtml
 
 
 class TypedList(Format):
@@ -25,7 +25,7 @@ class TypedList(Format):
 
         return j
 
-    def parse(self, file: io.TextIOWrapper, name, parsed_notes: [Note]) -> Note:
+    def parse(self, file: io.TextIOWrapper, name, parsed_notes: [Note], args) -> Note:
         line = file.readline()
         parsed_yaml = None
         # Find YAML header, or continue
@@ -41,9 +41,9 @@ class TypedList(Format):
 
         content = []
         relations = {}
-        tags = set()
+        tags = []
         while line:
-            if line.startswith("- ") and len(line) > 2:
+            if line.startswith(f"{args.typed_links_prefix} ") and len(line) > 2:
                 is_rel = True
                 index = self.parse_word(line, 2, breaks=PUNCTUATION)
                 type = line[2:index]
@@ -94,17 +94,21 @@ class TypedList(Format):
                         line = file.readline()
                         continue
             content.append(line)
-            tags.update(get_tags_from_line(line))
+            for tag in get_tags_from_line(line):
+                if tag not in tags:
+                    tags.append(tag)
             # TODO: Save aliases as Relation property
             for wikilink in get_wikilinks_from_line(line):
-                rel = Relationship("inline", properties={"context": line})
+                rel = Relationship("inline",
+                                   properties={"context": line,
+                                               "parsedContext": markdownToHtml(line) if args.convert_markdown else ""})
                 if wikilink in relations:
                     relations[wikilink].append(rel)
                 else:
                     relations[wikilink] = [rel]
             line = file.readline()
-
-        return Note(name, tags, "".join(content), out_rels=relations, properties=parsed_yaml if parsed_yaml else {})
+        raw_content = markdownToHtml("".join(content)) if args.convert_markdown else "".join(content)
+        return Note(name, tags, raw_content, out_rels=relations, properties=parsed_yaml if parsed_yaml else {})
 
     def write(self, file, parsed_notes: [Note]):
         raise NotImplementedError
\ No newline at end of file
